@@ -1,5 +1,3 @@
-from pathlib import Path
-
 from django.conf import settings
 from django.urls import path
 from django.views.static import serve
@@ -12,11 +10,9 @@ from findmydevice.views.location import LocationView
 from findmydevice.views.location_data_size import LocationDataSizeView
 from findmydevice.views.request_access import RequestAccessView
 from findmydevice.views.version import VersionView
+from findmydevice.views.web_page import FmdWebPageView
 
 
-WEB_PATH = Path(findmydevice.__file__).parent / 'web'
-assert WEB_PATH.is_dir(), f'Directory not found here: {WEB_PATH}'
-
 urlpatterns = [
     path('command', CommandView.as_view(), name='command'),
     path('location', LocationView.as_view(), name='location'),
@@ -27,7 +23,8 @@ urlpatterns = [
     path('push', PostPushLinkView.as_view(), name='push'),
     path('requestAccess', RequestAccessView.as_view(), name='request_access'),
     path('version', VersionView.as_view(), name='version'),
+    path('', FmdWebPageView.as_view(), name='fmd-web-page'),
 ]
 if settings.DEBUG:
     # TODO: Serve from real Web server ;)
-    urlpatterns.append(path('<path:path>', serve, {'document_root': WEB_PATH}))
+    urlpatterns.append(path('<path:path>', serve, {'document_root': findmydevice.WEB_PATH}))
