@@ -2,8 +2,8 @@ from django.http import HttpResponse
 from django.views import View
 
 from findmydevice.json_utils import parse_json
-from findmydevice.models import DeviceUser
-from findmydevice.models.device_user import get_device_user_by_token
+from findmydevice.models import Device
+from findmydevice.models.device import get_device_by_token
 
 
 class KeyView(View):
@@ -18,8 +18,8 @@ class KeyView(View):
         """
         put_data = parse_json(request)
         access_token = put_data['IDT']
-        index = int(put_data['Data'])  # noqa TODO: Use this index!
+        # index = int(put_data['Data'])  # TODO: Use this index!
 
-        device_user: DeviceUser = get_device_user_by_token(token=access_token)
-        privkey = device_user.privkey
+        device: Device = get_device_by_token(token=access_token)
+        privkey = device.privkey
         return HttpResponse(content_type='application/text', content=privkey)
