@@ -17,14 +17,25 @@ class RequestAccessView(View):
     /requestAccess
     """
 
-    def put(self, request):
+    def put(self, request):  # TODO: Add lock here!
+        """
+        Response access token.
+        """
         access_data = parse_json(request)
-        hashed_password = access_data['Data']
+
+        hashed_password = access_data.get('HashedPassword') or access_data.get('Data')
+        if not hashed_password:
+            logger.error('No hashed password from "HashedPassword" or "Data" !')
+            return HttpResponseBadRequest()
 
         # App sends hex digest in uppercase, the web page in lower case ;)
         hashed_password = hashed_password.lower()
 
-        device_id = access_data['IDT']
+        device_id = access_data.get('DeviceId') or access_data.get('IDT')
+        if not device_id:
+            logger.error('No "DeviceId" or "IDT" !')
+            return HttpResponseBadRequest()
+
         try:
             device_id = UUID(device_id)
         except ValueError as err:
