@@ -16,9 +16,16 @@ class FmdWebPageTests(HtmlAssertionMixin, TestCase):
 
     def test_anonymous(self):
         response = self.client.get('/')
-        self.assertRedirects(
-            response, expected_url='/admin/login/?next=/', fetch_redirect_response=False
+        self.assertTemplateUsed(response, template_name='fmd/login_info.html')
+        self.assert_html_parts(
+            response,
+            parts=(
+                '<title>Log in | Find My Device</title>',
+                '<p class="errornote">To find your device, you must be logged in.</p>',
+                '<a href="/admin/login/">Log in</a>',
+            ),
         )
+        assert_html_response_snapshot(response, query_selector=None, validate=False)
 
     def test_normal_user(self):
         self.client.force_login(self.normal_user)
